@@ -32,7 +32,7 @@ class GetMethod:
             if "." in newPath:
                 file_path_sufffix = newPath.split(".")[1]
                 file_path_name = newPath.split(".")[0]
-                if client.lower() == "android":
+                if client.lower() == "android" or platform.lower() == "server":
                     if file_path_sufffix == "java":
                         #print('文件名称')
                         #print(file_path_name)
@@ -44,7 +44,7 @@ class GetMethod:
                             if partnerId=='knowledge' and platform=='plugin':
                                 file_path=file_path_name
                             else:
-                                file_path=GetMethod.filePathRevert(file_path_name)
+                                file_path=GetMethod.filePathRevert(file_path_name,platform)
                             new_method_change = GetMethod.methodDiff(new_method_change, new_method, old_method,
                                                                      file_path,new_str,pre_str,cmtId,git_diiff_url)
                 elif client.lower() == "iphone":
@@ -60,6 +60,7 @@ class GetMethod:
                               old_method = GetMethod.getIosHeadMethodMd5(pre_str)  # 老的
                           new_method_change = GetMethod.methodDiff(new_method_change, new_method, old_method,newPath,cmtId,git_diiff_url)
         if len(new_method_change)!=0:
+           print(new_method_change)
            return new_method_change
 
 
@@ -77,7 +78,7 @@ class GetMethod:
         return b_result
 
     @staticmethod
-    def getParaGerritMethod(gerritId,client,gerritUrl,user,password,gerritProject):
+    def getParaGerritMethod(gerritId,client,gerritUrl,user,password,gerritProject,platform):
         if "https" in gerritUrl:
             auth = HTTPDigestAuth(user, password)
         else:
@@ -122,7 +123,7 @@ class GetMethod:
                                     new_str = GetMethod.getGerritNewStr(rest, gerritId, reversionId, file_path)
                                     new_method = GetMethod.getKtMethodMd5(new_str)  # 新提交的文件方法'''
                               # 老的
-                            fileRevertName=GetMethod.filePathRevert(file_path_name)
+                            fileRevertName=GetMethod.filePathRevert(file_path_name,platform)
                             new_method_change = GetMethod.methodDiff(new_method_change, new_method, old_method,
                                                                 fileRevertName,new_str,pre_str,changeId,cmitid_url)
                 elif client.lower() == "iphone":
@@ -151,12 +152,12 @@ class GetMethod:
         return new_method_change
 
     @staticmethod
-    def getGerritParallelRun(gerritIdList,client,gerritUrl,user,password,gerritProject):
+    def getGerritParallelRun(gerritIdList,client,gerritUrl,user,password,gerritProject,platform):
         items = gerritIdList
         results = []
         p = Pool(10)
         for item in items:
-            b = p.apply_async(GetMethod.getParaGerritMethod, (item, client,gerritUrl,user,password,gerritProject,))
+            b = p.apply_async(GetMethod.getParaGerritMethod, (item, client,gerritUrl,user,password,gerritProject,platform,))
             results.append(b)
         b_result = [item.get() for item in results]
         p.close()
@@ -540,32 +541,63 @@ class GetMethod:
         return file_method_list
 
     @staticmethod
-    def filePathRevert(file_path):
+    def filePathRevert(file_path,platform):
         #print(file_path)
-        if '/source' in file_path:
-            file = file_path.split('/source')
-        elif '/src' in file_path:
-            file = file_path.split('/src')
-        file_qian = file[0]
-        fileQ = file_qian.split('/')
-        index = len(fileQ) - 1
-        file_src_qian = fileQ[index]
-        file_hou = file[1]
-        if '/main/java' in file_hou:
-            fileH = file_hou.split('/main/java')
-            file_src_hou = fileH[1]
+        if platform=='server':
+            if '/source' in file_path:
+                file = file_path.split('/source')
+            elif '/src' in file_path:
+                file = file_path.split('/src')
+            elif 'src' in file_path:
+                file = file_path.split('src')
+            file_qian = file[0]
+            fileQ = file_qian.split('/')
+            index = len(fileQ) - 1
+            file_src_qian = fileQ[index]
+            file_hou = file[1]
+            if '/main/java' in file_hou:
+                fileH = file_hou.split('/main/java/')
+                file_src_hou = fileH[1]
 
-        elif '/org/' in file_hou:
-            fileH = file_hou.split('/org')
-            file_src_hou = '/org' + fileH[1]
+            elif '/org/' in file_hou:
+                fileH = file_hou.split('/org')
+                file_src_hou = 'org' + fileH[1]
 
-        elif '/com/' in file_hou:
-            fileH = file_hou.split('/com')
-            file_src_hou = '/com' + fileH[1]
+            elif '/com/' in file_hou:
+                fileH = file_hou.split('/com')
+                file_src_hou = 'com' + fileH[1]
+
+            else:
+                file_src_hou = file_hou
+
+            file_path_sdk = file_src_hou
 
         else:
-            file_src_hou = file_hou
-        file_path_sdk = file_src_qian + file_src_hou
+            if '/source' in file_path:
+                file = file_path.split('/source')
+            elif '/src' in file_path:
+                file = file_path.split('/src')
+            elif 'src' in file_path:
+                file = file_path.split('src')
+            file_qian = file[0]
+            fileQ = file_qian.split('/')
+            index = len(fileQ) - 1
+            file_src_qian = fileQ[index]
+            file_hou = file[1]
+            if '/main/java' in file_hou:
+                fileH = file_hou.split('/main/java')
+                file_src_hou = fileH[1]
 
+            elif '/org/' in file_hou:
+                fileH = file_hou.split('/org')
+                file_src_hou = '/org' + fileH[1]
 
+            elif '/com/' in file_hou:
+                fileH = file_hou.split('/com')
+                file_src_hou = '/com' + fileH[1]
+
+            else:
+                file_src_hou = file_hou
+
+            file_path_sdk = file_src_qian + file_src_hou
         return file_path_sdk
